@@ -17,6 +17,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "aurorae.h"
 #include "auroraetheme.h"
+#include "config-kwin.h"
 
 #include <QApplication>
 #include <QtDeclarative/QDeclarativeComponent>
@@ -27,6 +28,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <KConfig>
 #include <KConfigGroup>
+#include <KDebug>
+#include <KPluginInfo>
+#include <KServiceTypeTrader>
 #include <KStandardDirs>
 #include <Plasma/FrameSvg>
 
@@ -39,6 +43,7 @@ AuroraeFactory::AuroraeFactory()
         , m_theme(new AuroraeTheme(this))
         , m_engine(new QDeclarativeEngine(this))
         , m_component(new QDeclarativeComponent(m_engine, this))
+        , m_engineType(AuroraeEngine)
 {
     init();
 }
@@ -49,8 +54,32 @@ void AuroraeFactory::init()
 
     KConfig conf("auroraerc");
     KConfigGroup group(&conf, "Engine");
+    if (!group.hasKey("EngineType") && !group.hasKey("ThemeName")) {
+        // neither engine type and theme name are configured, use the only available theme
+        initQML(group);
+    } else if (group.hasKey("EngineType")) {
+        const QString engineType = group.readEntry("EngineType", "aurorae").toLower();
+        if (engineType == "qml") {
+            initQML(group);
+        } else {
+            // fallback to classic Aurorae Themes
+            initAurorae(conf, group);
+        }
+    } else {
+        // fallback to classic Aurorae Themes
+        initAurorae(conf, group);
+    }
+}
 
-    const QString themeName = group.readEntry("ThemeName", "example-deco");
+void AuroraeFactory::initAurorae(KConfig &conf, KConfigGroup &group)
+{
+    m_engineType = AuroraeEngine;
+    const QString themeName = group.readEntry("ThemeName");
+    if (themeName.isEmpty()) {
+        // no theme configured, fall back to Plastik QML theme
+        initQML(group);
+        return;
+    }
     KConfig config("aurorae/themes/" + themeName + '/' + themeName + "rc", KConfig::FullConfig, "data");
     KConfigGroup themeGroup(&conf, themeName);
     m_theme->loadTheme(themeName, config);
@@ -63,7 +92,40 @@ void AuroraeFactory::init()
     }
     m_component->loadUrl(QUrl(KStandardDirs::locate("data", "kwin/aurorae/aurorae.qml")));
     m_engine->rootContext()->setContextProperty("auroraeTheme", m_theme);
-    m_engine->rootContext()->setContextProperty("options", this);
+    m_themeName = themeName;
+}
+
+void AuroraeFactory::initQML(const KConfigGroup &group)
+{
+    // try finding the QML package
+    const QString themeName = group.readEntry("ThemeName", "kwin4_decoration_qml_plastik");
+    kDebug(1212) << "Trying to load QML Decoration " << themeName;
+    const QString internalname = themeName.toLower();
+
+    QString constraint = QString("[X-KDE-PluginInfo-Name] == '%1'").arg(internalname);
+    KService::List offers = KServiceTypeTrader::self()->query("KWin/Decoration", constraint);
+    if (offers.isEmpty()) {
+        kError(1212) << "Couldn't find QML Decoration " << themeName << endl;
+        // TODO: what to do in error case?
+        return;
+    }
+    KService::Ptr service = offers.first();
+    KPluginInfo plugininfo(service);
+    const QString pluginName = service->property("X-KDE-PluginInfo-Name").toString();
+    const QString scriptName = service->property("X-Plasma-MainScript").toString();
+    const QString file = KStandardDirs::locate("data", QLatin1String(KWIN_NAME) + "/decorations/" + pluginName + "/contents/" + scriptName);
+    if (file.isNull()) {
+        kDebug(1212) << "Could not find script file for " << pluginName;
+        // TODO: what to do in error case?
+        return;
+    }
+    m_engineType = QMLEngine;
+    // setup the QML engine
+    foreach (const QString &importPath, KGlobal::dirs()->findDirs("module", "imports")) {
+        m_engine->addImportPath(importPath);
+    }
+    m_component->loadUrl(QUrl::fromLocalFile(file));
+    m_themeName = themeName;
 }
 
 AuroraeFactory::~AuroraeFactory()
@@ -88,17 +150,28 @@ bool AuroraeFactory::reset(unsigned long changed)
     if (changed & SettingFont){
         emit titleFontChanged();
     }
+    if (changed & SettingCompositing) {
+        return false;
+    }
     const KConfig conf("auroraerc");
     const KConfigGroup group(&conf, "Engine");
     const QString themeName = group.readEntry("ThemeName", "example-deco");
     const KConfig config("aurorae/themes/" + themeName + '/' + themeName + "rc", KConfig::FullConfig, "data");
     const KConfigGroup themeGroup(&conf, themeName);
     if (themeName != m_theme->themeName()) {
-        m_theme->loadTheme(themeName, config);
-        resetDecorations(changed);
+        delete m_engine;
+        m_engine = new QDeclarativeEngine(this);
+        delete m_component;
+        m_component = new QDeclarativeComponent(m_engine, this);
+        init();
+        // recreate all decorations
+        return true;
     }
-    m_theme->setBorderSize((KDecorationDefines::BorderSize)themeGroup.readEntry<int>("BorderSize", KDecorationDefines::BorderNormal));
-    m_theme->setButtonSize((KDecorationDefines::BorderSize)themeGroup.readEntry<int>("ButtonSize", KDecorationDefines::BorderNormal));
+    if (m_engineType == AuroraeEngine) {
+        m_theme->setBorderSize((KDecorationDefines::BorderSize)themeGroup.readEntry<int>("BorderSize", KDecorationDefines::BorderNormal));
+        m_theme->setButtonSize((KDecorationDefines::BorderSize)themeGroup.readEntry<int>("ButtonSize", KDecorationDefines::BorderNormal));
+    }
+    emit configChanged();
     return false; // need hard reset
 }
 
@@ -107,6 +180,7 @@ bool AuroraeFactory::supports(Ability ability) const
     switch (ability) {
     case AbilityAnnounceButtons:
     case AbilityUsesAlphaChannel:
+    case AbilityAnnounceAlphaChannel:
     case AbilityButtonMenu:
     case AbilityButtonSpacer:
     case AbilityExtendIntoClientArea:
@@ -149,31 +223,6 @@ QDeclarativeItem *AuroraeFactory::createQmlDecoration(Aurorae::AuroraeClient *cl
     return qobject_cast< QDeclarativeItem* >(m_component->create(context));
 }
 
-QString AuroraeFactory::rightButtons()
-{
-    return options()->titleButtonsRight();
-}
-
-QString AuroraeFactory::leftButtons()
-{
-    return options()->titleButtonsLeft();
-}
-
-bool AuroraeFactory::customButtonPositions()
-{
-    return options()->customButtonPositions();
-}
-
-QFont AuroraeFactory::activeTitleFont()
-{
-    return options()->font();
-}
-
-QFont AuroraeFactory::inactiveTitleFont()
-{
-    return options()->font(false);
-}
-
 AuroraeFactory *AuroraeFactory::s_instance = NULL;
 
 /*******************************************************
@@ -187,6 +236,10 @@ AuroraeClient::AuroraeClient(KDecorationBridge *bridge, KDecorationFactory *fact
 {
     connect(this, SIGNAL(keepAboveChanged(bool)), SIGNAL(keepAboveChangedWrapper()));
     connect(this, SIGNAL(keepBelowChanged(bool)), SIGNAL(keepBelowChangedWrapper()));
+    connect(AuroraeFactory::instance(), SIGNAL(buttonsChanged()), SIGNAL(buttonsChanged()));
+    connect(AuroraeFactory::instance(), SIGNAL(configChanged()), SIGNAL(configChanged()));
+    connect(AuroraeFactory::instance(), SIGNAL(titleFontChanged()), SIGNAL(fontChanged()));
+    connect(m_item, SIGNAL(alphaChanged()), SLOT(slotAlphaChanged()));
 }
 
 AuroraeClient::~AuroraeClient()
@@ -222,9 +275,9 @@ void AuroraeClient::init()
     pal2.setColor(widget()->backgroundRole(), Qt::transparent);
     widget()->setPalette(pal2);
     m_scene->addItem(m_item);
+    slotAlphaChanged();
 
     AuroraeFactory::instance()->theme()->setCompositingActive(compositingActive());
-    connect(AuroraeFactory::instance()->theme(), SIGNAL(themeChanged()), SLOT(themeChanged()));
 }
 
 bool AuroraeClient::eventFilter(QObject *object, QEvent *event)
@@ -455,6 +508,8 @@ void AuroraeClient::themeChanged()
         m_item->setHeight(m_scene->sceneRect().height());
     }
     m_scene->addItem(m_item);
+    connect(m_item, SIGNAL(alphaChanged()), SLOT(slotAlphaChanged()));
+    slotAlphaChanged();
 }
 
 int AuroraeClient::doubleClickInterval() const
@@ -500,6 +555,23 @@ void AuroraeClient::doTitlebarDblClickOperation()
     KDecorationUnstable::titlebarDblClickOperation();
 }
 
+QVariant AuroraeClient::readConfig(const QString &key, const QVariant &defaultValue)
+{
+    KSharedConfigPtr config = KSharedConfig::openConfig("auroraerc");
+    return config->group(AuroraeFactory::instance()->currentThemeName()).readEntry(key, defaultValue);
+}
+
+void AuroraeClient::slotAlphaChanged()
+{
+    QVariant alphaProperty = m_item->property("alpha");
+    if (alphaProperty.isValid() && alphaProperty.canConvert<bool>()) {
+        setAlphaEnabled(alphaProperty.toBool());
+    } else {
+        // by default all Aurorae themes use the alpha channel
+        setAlphaEnabled(true);
+    }
+}
+
 } // namespace Aurorae
 
 extern "C"
