@@ -21,6 +21,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "effects.h"
 
+#include "effectsadaptor.h"
 #include "deleted.h"
 #include "client.h"
 #include "group.h"
@@ -52,6 +53,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <Plasma/Theme>
 
 #include <assert.h>
+#include "composite.h"
 
 
 namespace KWin
@@ -97,13 +99,19 @@ static void deleteWindowProperty(Window win, long int atom)
 
 //---------------------
 
-EffectsHandlerImpl::EffectsHandlerImpl(CompositingType type)
-    : EffectsHandler(type)
+EffectsHandlerImpl::EffectsHandlerImpl(Compositor *compositor, Scene *scene)
+    : EffectsHandler(scene->compositingType())
     , keyboard_grab_effect(NULL)
     , fullscreen_effect(0)
     , next_window_quad_type(EFFECT_QUAD_TYPE_START)
     , mouse_poll_ref_count(0)
+    , m_compositor(compositor)
+    , m_scene(scene)
 {
+    new EffectsAdaptor(this);
+    QDBusConnection dbus = QDBusConnection::sessionBus();
+    dbus.registerObject("/Effects", this);
+    dbus.registerService("org.kde.kwin.Effects");
     // init is important, otherwise causes crashes when quads are build before the first painting pass start
     m_currentBuildQuadsIterator = m_activeEffects.end();
 
@@ -243,7 +251,7 @@ void EffectsHandlerImpl::paintScreen(int mask, QRegion region, ScreenPaintData&
         (*m_currentPaintScreenIterator++)->paintScreen(mask, region, data);
         --m_currentPaintScreenIterator;
     } else
-        scene->finalPaintScreen(mask, region, data);
+        m_scene->finalPaintScreen(mask, region, data);
 }
 
 void EffectsHandlerImpl::postPaintScreen()
@@ -270,7 +278,7 @@ void EffectsHandlerImpl::paintWindow(EffectWindow* w, int mask, QRegion region,
         (*m_currentPaintWindowIterator++)->paintWindow(w, mask, region, data);
         --m_currentPaintWindowIterator;
     } else
-        scene->finalPaintWindow(static_cast<EffectWindowImpl*>(w), mask, region, data);
+        m_scene->finalPaintWindow(static_cast<EffectWindowImpl*>(w), mask, region, data);
 }
 
 void EffectsHandlerImpl::paintEffectFrame(EffectFrame* frame, QRegion region, double opacity, double frameOpacity)
@@ -307,7 +315,7 @@ void EffectsHandlerImpl::drawWindow(EffectWindow* w, int mask, QRegion region, W
         (*m_currentDrawWindowIterator++)->drawWindow(w, mask, region, data);
         --m_currentDrawWindowIterator;
     } else
-        scene->finalDrawWindow(static_cast<EffectWindowImpl*>(w), mask, region, data);
+        m_scene->finalDrawWindow(static_cast<EffectWindowImpl*>(w), mask, region, data);
 }
 
 void EffectsHandlerImpl::buildQuads(EffectWindow* w, WindowQuadList& quadList)
@@ -409,6 +417,12 @@ void EffectsHandlerImpl::slotClientAdded(Client *c)
         connect(c, SIGNAL(windowShown(KWin::Toplevel*)), SLOT(slotClientShown(KWin::Toplevel*)));
 }
 
+void EffectsHandlerImpl::slotUnmanagedAdded(Unmanaged *u)
+{   // regardless, unmanaged windows are -yet?- not synced anyway
+    setupUnmanagedConnections(u);
+    emit windowAdded(u->effectWindow());
+}
+
 void EffectsHandlerImpl::slotClientShown(KWin::Toplevel *t)
 {
     Q_ASSERT(dynamic_cast<Client*>(t));
@@ -418,22 +432,6 @@ void EffectsHandlerImpl::slotClientShown(KWin::Toplevel *t)
         emit windowAdded(c->effectWindow());
 }
 
-void EffectsHandlerImpl::slotUnmanagedAdded(Unmanaged *u)
-{
-    if (u->readyForPainting())
-        slotUnmanagedShown(u);
-    else
-        connect(u, SIGNAL(windowShown(KWin::Toplevel*)), SLOT(slotUnmanagedShown(KWin::Toplevel*)));
-}
-
-void EffectsHandlerImpl::slotUnmanagedShown(KWin::Toplevel *t)
-{
-    Q_ASSERT(dynamic_cast<Unmanaged*>(t));
-    Unmanaged *u = static_cast<Unmanaged*>(t);
-    setupUnmanagedConnections(u);
-    emit windowAdded(u->effectWindow());
-}
-
 void EffectsHandlerImpl::slotDeletedRemoved(KWin::Deleted *d)
 {
     emit windowDeleted(d->effectWindow());
@@ -521,7 +519,7 @@ void EffectsHandlerImpl::slotPaddingChanged(Toplevel* t, const QRect& old)
 void EffectsHandlerImpl::setActiveFullScreenEffect(Effect* e)
 {
     fullscreen_effect = e;
-    Workspace::self()->checkUnredirect();
+    m_compositor->checkUnredirect();
 }
 
 Effect* EffectsHandlerImpl::activeFullScreenEffect() const
@@ -577,7 +575,7 @@ void* EffectsHandlerImpl::getProxy(QString name)
 void EffectsHandlerImpl::startMousePolling()
 {
     if (!mouse_poll_ref_count)   // Start timer if required
-        Workspace::self()->startMousePolling();
+        m_compositor->startMousePolling();
     mouse_poll_ref_count++;
 }
 
@@ -586,7 +584,7 @@ void EffectsHandlerImpl::stopMousePolling()
     assert(mouse_poll_ref_count);
     mouse_poll_ref_count--;
     if (!mouse_poll_ref_count)   // Stop timer if required
-        Workspace::self()->stopMousePolling();
+        m_compositor->stopMousePolling();
 }
 
 bool EffectsHandlerImpl::hasKeyboardGrab() const
@@ -596,9 +594,8 @@ bool EffectsHandlerImpl::hasKeyboardGrab() const
 
 void EffectsHandlerImpl::desktopResized(const QSize &size)
 {
-    scene->screenGeometryChanged(size);
+    m_scene->screenGeometryChanged(size);
     emit screenGeometryChanged(size);
-    Workspace::self()->addRepaintFull();
 }
 
 void EffectsHandlerImpl::slotPropertyNotify(Toplevel* t, long int atom)
@@ -920,22 +917,22 @@ EffectWindow* EffectsHandlerImpl::currentTabBoxWindow() const
 
 void EffectsHandlerImpl::addRepaintFull()
 {
-    Workspace::self()->addRepaintFull();
+    m_compositor->addRepaintFull();
 }
 
 void EffectsHandlerImpl::addRepaint(const QRect& r)
 {
-    Workspace::self()->addRepaint(r);
+    m_compositor->addRepaint(r);
 }
 
 void EffectsHandlerImpl::addRepaint(const QRegion& r)
 {
-    Workspace::self()->addRepaint(r);
+    m_compositor->addRepaint(r);
 }
 
 void EffectsHandlerImpl::addRepaint(int x, int y, int w, int h)
 {
-    Workspace::self()->addRepaint(x, y, w, h);
+    m_compositor->addRepaint(x, y, w, h);
 }
 
 int EffectsHandlerImpl::activeScreen() const
@@ -974,23 +971,52 @@ QRect EffectsHandlerImpl::clientArea(clientAreaOption opt, const QPoint& p, int
 
 Window EffectsHandlerImpl::createInputWindow(Effect* e, int x, int y, int w, int h, const QCursor& cursor)
 {
-    XSetWindowAttributes attrs;
-    attrs.override_redirect = True;
-    Window win = XCreateWindow(display(), rootWindow(), x, y, w, h, 0, 0, InputOnly, CopyFromParent,
-                               CWOverrideRedirect, &attrs);
-    // TODO keeping on top?
-    // TODO enter/leave notify?
-    XSelectInput(display(), win, ButtonPressMask | ButtonReleaseMask | PointerMotionMask);
-    XDefineCursor(display(), win, cursor.handle());
-    XMapWindow(display(), win);
-    input_windows.append(qMakePair(e, win));
-
+    Window win = 0;
+    QList<InputWindowPair>::iterator it = input_windows.begin();
+    while (it != input_windows.end()) {
+        if (it->first != e) {
+            ++it;
+            continue;
+        }
+        XWindowAttributes attr;
+        if (!XGetWindowAttributes(display(), it->second, &attr)) {
+            // this is some random junk that certainly should no be here
+            kDebug(1212) << "found input window that is NOT on the server, something is VERY broken here";
+            Q_ASSERT(false); // exit in debug mode - for releases we'll be a bit more graceful
+            it = input_windows.erase(it);
+            continue;
+        }
+        if (attr.x == x && attr.y == y && attr.width == w && attr.height == h) {
+            win = it->second; // re-use
+            break;
+        } else if (attr.map_state == IsUnmapped) {
+            // probably old one, likely no longer of interest
+            XDestroyWindow(display(), it->second);
+            it = input_windows.erase(it);
+            continue;
+        }
+        ++it;
+    }
+    if (!win) {
+        XSetWindowAttributes attrs;
+        attrs.override_redirect = True;
+        win = XCreateWindow(display(), rootWindow(), x, y, w, h, 0, 0, InputOnly, CopyFromParent,
+                                CWOverrideRedirect, &attrs);
+        // TODO keeping on top?
+        // TODO enter/leave notify?
+        XSelectInput(display(), win, ButtonPressMask | ButtonReleaseMask | PointerMotionMask);
+        XDefineCursor(display(), win, cursor.handle());
+        input_windows.append(qMakePair(e, win));
+    }
+    XMapRaised(display(), win);
     // Raise electric border windows above the input windows
     // so they can still be triggered.
 #ifdef KWIN_BUILD_SCREENEDGES
     Workspace::self()->screenEdge()->ensureOnTop();
 #endif
-
+    if (input_windows.count() > 10) // that sounds like some leak - could still be correct, thoug - so NO ABORT HERE!
+        kDebug() << "** warning ** there are now " << input_windows.count() <<
+                    "input windows what's a bit much - please have a look and if this counts up, better report a bug";
     return win;
 }
 
@@ -998,8 +1024,7 @@ void EffectsHandlerImpl::destroyInputWindow(Window w)
 {
     foreach (const InputWindowPair & pos, input_windows) {
         if (pos.second == w) {
-            input_windows.removeAll(pos);
-            XDestroyWindow(display(), w);
+            XUnmapWindow(display(), w);
 #ifdef KWIN_BUILD_SCREENEDGES
             Workspace::self()->screenEdge()->raisePanelProxies();
 #endif
@@ -1054,17 +1079,23 @@ void EffectsHandlerImpl::checkInputWindowStacking()
 {
     if (input_windows.count() == 0)
         return;
-    Window* wins = new Window[ input_windows.count()];
+    Window* wins = new Window[input_windows.count()];
     int pos = 0;
-    foreach (const InputWindowPair & it, input_windows)
-    wins[ pos++ ] = it.second;
-    XRaiseWindow(display(), wins[ 0 ]);
-    XRestackWindows(display(), wins, pos);
+    foreach (const InputWindowPair &it, input_windows) {
+        XWindowAttributes attr;
+        if (XGetWindowAttributes(display(), it.second, &attr) && attr.map_state != IsUnmapped)
+            wins[pos++] = it.second;
+    }
+    if (pos) {
+        XRaiseWindow(display(), wins[0]);
+        XRestackWindows(display(), wins, pos);
+    }
     delete[] wins;
     // Raise electric border windows above the input windows
     // so they can still be triggered. TODO: Do both at once.
 #ifdef KWIN_BUILD_SCREENEDGES
-    Workspace::self()->screenEdge()->ensureOnTop();
+    if (pos)
+        Workspace::self()->screenEdge()->ensureOnTop();
 #endif
 }
 
@@ -1113,7 +1144,7 @@ void EffectsHandlerImpl::reserveElectricBorderSwitching(bool reserve, Qt::Orient
 unsigned long EffectsHandlerImpl::xrenderBufferPicture()
 {
 #ifdef KWIN_HAVE_XRENDER_COMPOSITING
-    if (SceneXrender* s = dynamic_cast< SceneXrender* >(scene))
+    if (SceneXrender* s = dynamic_cast< SceneXrender* >(m_scene))
         return s->bufferPicture();
 #endif
     return None;
@@ -1169,7 +1200,7 @@ QStringList EffectsHandlerImpl::listOfEffects() const
 
 bool EffectsHandlerImpl::loadEffect(const QString& name, bool checkDefault)
 {
-    Workspace::self()->addRepaintFull();
+    m_compositor->addRepaintFull();
 
     if (!name.startsWith(QLatin1String("kwin4_effect_")))
         kWarning(1212) << "Effect names usually have kwin4_effect_ prefix" ;
@@ -1313,7 +1344,7 @@ bool EffectsHandlerImpl::loadScriptedEffect(const QString& name, KService *servi
 
 void EffectsHandlerImpl::unloadEffect(const QString& name)
 {
-    Workspace::self()->addRepaintFull();
+    m_compositor->addRepaintFull();
 
     for (QMap< int, EffectPair >::iterator it = effect_order.begin(); it != effect_order.end(); ++it) {
         if (it.value().first == name) {
@@ -1644,8 +1675,8 @@ EffectFrameImpl::EffectFrameImpl(EffectFrameStyle style, bool staticSize, QPoint
     m_selection.setCacheAllRenderedFrames(true);
     m_selection.setEnabledBorders(Plasma::FrameSvg::AllBorders);
 
-    if (effects->compositingType() == OpenGLCompositing) {
-        m_sceneFrame = new SceneOpenGL::EffectFrame(this);
+    if (effects->isOpenGLCompositing()) {
+        m_sceneFrame = new SceneOpenGL::EffectFrame(this, static_cast<SceneOpenGL*>(Compositor::self()->scene()));
     } else if (effects->compositingType() == XRenderCompositing) {
 #ifdef KWIN_HAVE_XRENDER_COMPOSITING
         m_sceneFrame = new SceneXrender::EffectFrame(this);
