@@ -20,12 +20,13 @@
 
 #include "blur.h"
 #include "blurshader.h"
+// KConfigSkeleton
+#include "blurconfig.h"
 
 #include <X11/Xatom.h>
 
 #include <QMatrix4x4>
 #include <QLinkedList>
-#include <KConfigGroup>
 #include <KDebug>
 
 namespace KWin
@@ -54,7 +55,7 @@ BlurEffect::BlurEffect()
 
     // ### Hackish way to announce support.
     //     Should be included in _NET_SUPPORTED instead.
-    if (shader->isValid() && target->valid()) {
+    if (shader && shader->isValid() && target->valid()) {
         XChangeProperty(display(), rootWindow(), net_wm_blur_region, net_wm_blur_region,
                         32, PropModeReplace, 0, 0);
     } else {
@@ -86,15 +87,16 @@ void BlurEffect::reconfigure(ReconfigureFlags flags)
 {
     Q_UNUSED(flags)
 
-    KConfigGroup cg = EffectsHandler::effectConfig("Blur");
-    int radius = qBound(2, cg.readEntry("BlurRadius", 12), 14);
-    shader->setRadius(radius);
+    BlurConfig::self()->readConfig();
+    int radius = qBound(2, BlurConfig::blurRadius(), 14);
+    if (shader)
+        shader->setRadius(radius);
 
-    m_shouldCache = cg.readEntry("CacheTexture", true);
+    m_shouldCache = BlurConfig::cacheTexture();
 
     windows.clear();
 
-    if (!shader->isValid())
+    if (!shader || !shader->isValid())
         XDeleteProperty(display(), rootWindow(), net_wm_blur_region);
 }
 
@@ -153,7 +155,7 @@ bool BlurEffect::enabledByDefault()
 
     if (gl->isIntel() && gl->chipClass() < SandyBridge)
         return false;
-    if (gl->driver() == Driver_Catalyst) {
+    if (gl->driver() == Driver_Catalyst && effects->compositingType() == OpenGL1Compositing) {
         // fglrx supports only ARB shaders and those tend to crash KWin (see Bug #270818 and #286795)
         return false;
     }
@@ -163,8 +165,12 @@ bool BlurEffect::enabledByDefault()
 
 bool BlurEffect::supported()
 {
-    bool supported = GLRenderTarget::supported() && GLTexture::NPOTTextureSupported() &&
-                     (GLSLBlurShader::supported() || ARBBlurShader::supported());
+    bool supported = GLRenderTarget::supported() && GLTexture::NPOTTextureSupported() && GLSLBlurShader::supported();
+#ifdef KWIN_HAVE_OPENGL_1
+    if (effects->compositingType() == OpenGL1Compositing) {
+        supported = GLRenderTarget::supported() && GLTexture::NPOTTextureSupported() && ARBBlurShader::supported();
+    }
+#endif
 
     if (supported) {
         int maxTexSize;
@@ -201,7 +207,7 @@ QRegion BlurEffect::blurRegion(const EffectWindow *w) const
     if (value.isValid()) {
         const QRegion appRegion = qvariant_cast<QRegion>(value);
         if (!appRegion.isEmpty()) {
-            if (w->hasDecoration() && effects->decorationSupportsBlurBehind()) {
+            if (w->decorationHasAlpha() && effects->decorationSupportsBlurBehind()) {
                 region = w->shape();
                 region -= w->decorationInnerRect();
             }
@@ -212,7 +218,7 @@ QRegion BlurEffect::blurRegion(const EffectWindow *w) const
             // for the whole window.
             region = w->shape();
         }
-    } else if (w->hasDecoration() && effects->decorationSupportsBlurBehind()) {
+    } else if (w->decorationHasAlpha() && effects->decorationSupportsBlurBehind()) {
         // If the client hasn't specified a blur region, we'll only enable
         // the effect behind the decoration.
         region = w->shape();
@@ -261,6 +267,9 @@ void BlurEffect::prePaintWindow(EffectWindow* w, WindowPrePaintData& data, int t
     if (!w->isPaintingEnabled()) {
         return;
     }
+    if (!shader || !shader->isValid()) {
+        return;
+    }
 
     // to blur an area partially we have to shrink the opaque area of a window
     QRegion newClip;
@@ -355,7 +364,7 @@ void BlurEffect::prePaintWindow(EffectWindow* w, WindowPrePaintData& data, int t
 
 bool BlurEffect::shouldBlur(const EffectWindow *w, int mask, const WindowPaintData &data) const
 {
-    if (!target->valid() || !shader->isValid())
+    if (!target->valid() || !shader || !shader->isValid())
         return false;
 
     if (effects->activeFullScreenEffect() && !w->data(WindowForceBlurRole).toBool())
@@ -364,8 +373,8 @@ bool BlurEffect::shouldBlur(const EffectWindow *w, int mask, const WindowPaintDa
     if (w->isDesktop())
         return false;
 
-    bool scaled = !qFuzzyCompare(data.xScale, 1.0) && !qFuzzyCompare(data.yScale, 1.0);
-    bool translated = data.xTranslate || data.yTranslate;
+    bool scaled = !qFuzzyCompare(data.xScale(), 1.0) && !qFuzzyCompare(data.yScale(), 1.0);
+    bool translated = data.xTranslation() || data.yTranslation();
 
     if (scaled || ((translated || (mask & PAINT_WINDOW_TRANSFORMED)) && !w->data(WindowForceBlurRole).toBool()))
         return false;
@@ -385,18 +394,18 @@ void BlurEffect::drawWindow(EffectWindow *w, int mask, QRegion region, WindowPai
     if (shouldBlur(w, mask, data)) {
         QRegion shape = region & blurRegion(w).translated(w->pos()) & screen;
 
-        const bool translated = data.xTranslate || data.yTranslate;
+        const bool translated = data.xTranslation() || data.yTranslation();
         // let's do the evil parts - someone wants to blur behind a transformed window
         if (translated) {
-            shape = shape.translated(data.xTranslate, data.yTranslate);
+            shape = shape.translated(data.xTranslation(), data.yTranslation());
             shape = shape & region;
         }
 
         if (!shape.isEmpty()) {
             if (m_shouldCache && !translated) {
-                doCachedBlur(w, region, data.opacity * data.contents_opacity);
+                doCachedBlur(w, region, data.opacity());
             } else {
-                doBlur(shape, screen, data.opacity * data.contents_opacity);
+                doBlur(shape, screen, data.opacity());
             }
         }
     }
@@ -408,7 +417,7 @@ void BlurEffect::drawWindow(EffectWindow *w, int mask, QRegion region, WindowPai
 void BlurEffect::paintEffectFrame(EffectFrame *frame, QRegion region, double opacity, double frameOpacity)
 {
     const QRect screen(0, 0, displayWidth(), displayHeight());
-    bool valid = target->valid() && shader->isValid();
+    bool valid = target->valid() && shader && shader->isValid();
     QRegion shape = frame->geometry().adjusted(-5, -5, 5, 5) & screen;
     if (valid && !shape.isEmpty() && region.intersects(shape.boundingRect()) && frame->style() != EffectFrameNone) {
         doBlur(shape, screen, opacity * frameOpacity);
@@ -441,8 +450,8 @@ void BlurEffect::doBlur(const QRegion& shape, const QRect& screen, const float o
 
     // Set up the texture matrix to transform from screen coordinates
     // to texture coordinates.
-#ifndef KWIN_HAVE_OPENGLES
-    if (!ShaderManager::instance()->isValid()) {
+#ifdef KWIN_HAVE_OPENGL_1
+    if (effects->compositingType() == OpenGL1Compositing) {
         glMatrixMode(GL_TEXTURE);
         pushMatrix();
     }
@@ -483,8 +492,8 @@ void BlurEffect::doBlur(const QRegion& shape, const QRect& screen, const float o
 
     drawRegion(shape);
 
-#ifndef KWIN_HAVE_OPENGLES
-    if (!ShaderManager::instance()->isValid()) {
+#ifdef KWIN_HAVE_OPENGL_1
+    if (effects->compositingType() == OpenGL1Compositing) {
         popMatrix();
         glMatrixMode(GL_MODELVIEW);
     }
@@ -530,8 +539,8 @@ void BlurEffect::doCachedBlur(EffectWindow *w, const QRegion& region, const floa
     shader->bind();
     QMatrix4x4 textureMatrix;
     QMatrix4x4 modelViewProjectionMatrix;
-#ifndef KWIN_HAVE_OPENGLES
-    if (!ShaderManager::instance()->isValid()) {
+#ifdef KWIN_HAVE_OPENGL_1
+    if (effects->compositingType() == OpenGL1Compositing) {
         glMatrixMode(GL_MODELVIEW);
         pushMatrix();
         glLoadIdentity();
@@ -602,8 +611,8 @@ void BlurEffect::doCachedBlur(EffectWindow *w, const QRegion& region, const floa
         // to texture coordinates.
         textureMatrix.scale(1.0 / tex.width(), -1.0 / tex.height(), 1);
         textureMatrix.translate(-updateRect.x(), -updateRect.height() - updateRect.y(), 0);
-#ifndef KWIN_HAVE_OPENGLES
-        if (!ShaderManager::instance()->isValid()) {
+#ifdef KWIN_HAVE_OPENGL_1
+        if (effects->compositingType() == OpenGL1Compositing) {
             glMatrixMode(GL_TEXTURE);
             loadMatrix(textureMatrix);
             glMatrixMode(GL_PROJECTION);
@@ -643,8 +652,8 @@ void BlurEffect::doCachedBlur(EffectWindow *w, const QRegion& region, const floa
     textureMatrix.setToIdentity();
     textureMatrix.scale(1.0 / targetTexture.width(), -1.0 / targetTexture.height(), 1);
     textureMatrix.translate(-r.x(), -targetTexture.height() - r.y(), 0);
-#ifndef KWIN_HAVE_OPENGLES
-    if (!ShaderManager::instance()->isValid()) {
+#ifdef KWIN_HAVE_OPENGL_1
+    if (effects->compositingType() == OpenGL1Compositing) {
         glMatrixMode(GL_TEXTURE);
         loadMatrix(textureMatrix);
         glMatrixMode(GL_PROJECTION);
@@ -654,8 +663,8 @@ void BlurEffect::doCachedBlur(EffectWindow *w, const QRegion& region, const floa
 
     drawRegion(blurredRegion & region);
 
-#ifndef KWIN_HAVE_OPENGLES
-    if (!ShaderManager::instance()->isValid()) {
+#ifdef KWIN_HAVE_OPENGL_1
+    if (effects->compositingType() == OpenGL1Compositing) {
         popMatrix();
         glMatrixMode(GL_TEXTURE);
         popMatrix();
@@ -674,6 +683,9 @@ void BlurEffect::doCachedBlur(EffectWindow *w, const QRegion& region, const floa
 
 int BlurEffect::blurRadius() const
 {
+    if (!shader) {
+        return 0;
+    }
     return shader->radius();
 }
 
