@@ -77,13 +77,11 @@ void SnapHelperEffect::postPaintScreen()
     effects->postPaintScreen();
     if (m_timeline.currentValue() != 0.0) {
         // Display the guide
-        if (effects->compositingType() == OpenGLCompositing) {
+        if (effects->isOpenGLCompositing()) {
             GLVertexBuffer *vbo = GLVertexBuffer::streamingBuffer();
             vbo->reset();
             vbo->setUseColor(true);
-            if (ShaderManager::instance()->isValid()) {
-                ShaderManager::instance()->pushShader(ShaderManager::ColorShader);
-            }
+            ShaderBinder binder(ShaderManager::ColorShader);
             glEnable(GL_BLEND);
             glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 
@@ -122,9 +120,6 @@ void SnapHelperEffect::postPaintScreen()
             }
             vbo->setData(verts.count() / 2, 2, verts.data(), NULL);
             vbo->render(GL_LINES);
-            if (ShaderManager::instance()->isValid()) {
-                ShaderManager::instance()->popShader();
-            }
 
             glDisable(GL_BLEND);
             glLineWidth(1.0);
