@@ -26,6 +26,10 @@
 #include <kcmodule.h>
 #include <config-workspace.h>
 
+#include "ui_advanced.h"
+#include "ui_focus.h"
+#include "ui_moving.h"
+
 class QRadioButton;
 class QCheckBox;
 class QPushButton;
@@ -50,6 +54,31 @@ class KIntNumInput;
 #define  FOCUS_UNDER_MOUSE            2
 #define  FOCUS_STRICTLY_UNDER_MOUSE   3
 
+
+class KWinFocusConfigForm : public QWidget, public Ui::KWinFocusConfigForm
+{
+    Q_OBJECT
+
+public:
+    explicit KWinFocusConfigForm(QWidget* parent);
+};
+
+class KWinMovingConfigForm : public QWidget, public Ui::KWinMovingConfigForm
+{
+    Q_OBJECT
+
+public:
+    explicit KWinMovingConfigForm(QWidget* parent);
+};
+
+class KWinAdvancedConfigForm : public QWidget, public Ui::KWinAdvancedConfigForm
+{
+    Q_OBJECT
+
+public:
+    explicit KWinAdvancedConfigForm(QWidget* parent);
+};
+
 class KFocusConfig : public KCModule
 {
     Q_OBJECT
@@ -69,7 +98,6 @@ private slots:
     void focusPolicyChanged();
     void autoRaiseOnTog(bool);//CT 23Oct1998
     void delayFocusOnTog(bool);
-    void clickRaiseOnTog(bool);
     void updateActiveMouseScreen();
     void changed() {
         emit KCModule::changed(true);
@@ -91,24 +119,11 @@ private:
     void setActiveMouseScreen(bool);
 
     void setFocusStealing(int);
-    KComboBox* focusStealing;
-
-    //QGroupBox *fcsBox;
-    QWidget* fcsBox;
-    KComboBox *focusCombo;
-    QLabel *autoRaiseOnLabel;
-    QCheckBox *autoRaiseOn;
-    QLabel *delayFocusOnLabel;
-    QCheckBox *clickRaiseOn;
-    KIntNumInput *autoRaise;
-    KIntNumInput *delayFocus;
-    QCheckBox *separateScreenFocus;
-    QCheckBox *activeMouseScreen;
-    QWidget *focusNextToMouseContainer;
-    QCheckBox *focusNextToMouse;
 
     KConfig *config;
     bool     standAlone;
+
+    KWinFocusConfigForm *m_ui;
 };
 
 class KMovingConfig : public KCModule
@@ -129,9 +144,6 @@ private slots:
     void changed() {
         emit KCModule::changed(true);
     }
-    void slotBrdrSnapChanged(int);
-    void slotWndwSnapChanged(int);
-    void slotCntrSnapChanged(int);
 
 private:
     bool getGeometryTip(void);   //KS
@@ -139,12 +151,9 @@ private:
     void setGeometryTip(bool); //KS
     void setMoveResizeMaximized(bool);
 
-    KButtonGroup *windowsBox;
-    QCheckBox *geometryTipOn;
-    QCheckBox *moveResizeMaximized;
-
     KConfig *config;
     bool     standAlone;
+    KWinMovingConfigForm *m_ui;
 
     int getBorderSnapZone();
     void setBorderSnapZone(int);
@@ -153,11 +162,6 @@ private:
     int getCenterSnapZone();
     void setCenterSnapZone(int);
 
-    KButtonGroup *MagicBox;
-    QLabel *BrdrSnapLabel, *WndwSnapLabel, *CntrSnapLabel;
-    KIntNumInput *BrdrSnap, *WndwSnap, *CntrSnap;
-    QCheckBox *OverlapSnap;
-
 };
 
 class KAdvancedConfig : public KCModule
@@ -181,48 +185,20 @@ private slots:
         emit KCModule::changed(true);
     }
 
-    void tilingOnChanged(bool a);
 private:
 
     int getShadeHoverInterval(void);
     void setShadeHover(bool);
     void setShadeHoverInterval(int);
 
-    KButtonGroup *shBox;
-    KButtonGroup *wtBox;
-    QCheckBox *shadeHoverOn;
-    QLabel *shadeHoverLabel;
-    KIntNumInput *shadeHover;
-
     KConfig *config;
     bool     standAlone;
+    KWinAdvancedConfigForm *m_ui;
 
     void setHideUtilityWindowsForInactive(bool);
-    QCheckBox* hideUtilityWindowsForInactive;
-
     void setInactiveTabsSkipTaskbar(bool);
-    QCheckBox* inactiveTabsSkipTaskbar;
-
     void setAutogroupSimilarWindows(bool);
-    QCheckBox* autogroupSimilarWindows;
-
     void setAutogroupInForeground(bool);
-    QCheckBox* autogroupInForeground;
-
-    KComboBox *placementCombo;
-
-    // ------------------------------
-    // Tiling related widgets/methods
-    // ------------------------------
-    KButtonGroup *tilBox;
-    QCheckBox *tilingOn;
-    QLabel *tilingLayoutLabel;
-    QLabel *tilingRaiseLabel;
-    KComboBox *tilingLayoutCombo;
-    KComboBox *tilingRaiseCombo;
-    void setTilingOn(bool);
-    void setTilingLayout(int);
-    void setTilingRaisePolicy(int);
 };
 
 #endif // KKWMWINDOWS_H
