@@ -125,9 +125,6 @@ Options::Options(QObject *parent)
     , m_delayFocusInterval(Options::defaultDelayFocusInterval())
     , m_shadeHover(Options::defaultShadeHover())
     , m_shadeHoverInterval(Options::defaultShadeHoverInterval())
-    , m_tilingOn(Options::defaultTiling())
-    , m_tilingLayout(Options::defaultTilingLayout())
-    , m_tilingRaisePolicy(Options::defaultTilingRaisePolicy())
     , m_separateScreenFocus(Options::defaultSeparateScreenFocus())
     , m_activeMouseScreen(Options::defaultActiveMouseScreen())
     , m_placement(Options::defaultPlacement())
@@ -151,6 +148,7 @@ Options::Options(QObject *parent)
     , m_unredirectFullscreen(Options::defaultUnredirectFullscreen())
     , m_glSmoothScale(Options::defaultGlSmoothScale())
     , m_glVSync(Options::defaultGlVSync())
+    , m_colorCorrected(Options::defaultColorCorrected())
     , m_xrenderSmoothScale(Options::defaultXrenderSmoothScale())
     , m_maxFpsInterval(Options::defaultMaxFpsInterval())
     , m_refreshRate(Options::defaultRefreshRate())
@@ -158,6 +156,7 @@ Options::Options(QObject *parent)
     , m_glDirect(Options::defaultGlDirect())
     , m_glStrictBinding(Options::defaultGlStrictBinding())
     , m_glStrictBindingFollowsDriver(Options::defaultGlStrictBindingFollowsDriver())
+    , m_glLegacy(Options::defaultGlLegacy())
     , OpTitlebarDblClick(Options::defaultOperationTitlebarDblClick())
     , CmdActiveTitlebar1(Options::defaultCommandActiveTitlebar1())
     , CmdActiveTitlebar2(Options::defaultCommandActiveTitlebar2())
@@ -189,8 +188,10 @@ Options::Options(QObject *parent)
     , electric_border_pushback_pixels(Options::defaultElectricBorderPushbackPixels())
     , electric_border_maximize(Options::defaultElectricBorderMaximize())
     , electric_border_tiling(Options::defaultElectricBorderTiling())
+    , electric_border_corner_ratio(Options::defaultElectricBorderCornerRatio())
     , borderless_maximized_windows(Options::defaultBorderlessMaximizedWindows())
     , show_geometry_tip(Options::defaultShowGeometryTip())
+    , condensed_title(Options::defaultCondensedTitle())
     , animationSpeed(Options::defaultAnimationSpeed())
 {
 }
@@ -293,33 +294,6 @@ void Options::setShadeHoverInterval(int shadeHoverInterval)
     emit shadeHoverIntervalChanged();
 }
 
-void Options::setTiling(bool tiling)
-{
-    if (m_tilingOn == tiling) {
-        return;
-    }
-    m_tilingOn = tiling;
-    emit tilingChanged();
-}
-
-void Options::setTilingLayout(int tilingLayout)
-{
-    if (m_tilingLayout == static_cast<TilingLayoutFactory::Layouts>(tilingLayout)) {
-        return;
-    }
-    m_tilingLayout = static_cast<TilingLayoutFactory::Layouts>(tilingLayout);
-    emit tilingLayoutChanged();
-}
-
-void Options::setTilingRaisePolicy(int tilingRaisePolicy)
-{
-    if (m_tilingRaisePolicy == tilingRaisePolicy) {
-        return;
-    }
-    m_tilingRaisePolicy = tilingRaisePolicy;
-    emit tilingRaisePolicyChanged();
-}
-
 void Options::setSeparateScreenFocus(bool separateScreenFocus)
 {
     if (m_separateScreenFocus == separateScreenFocus) {
@@ -566,6 +540,15 @@ void Options::setShowGeometryTip(bool showGeometryTip)
     emit showGeometryTipChanged();
 }
 
+void Options::setCondensedTitle(bool condensedTitle)
+{
+    if (condensed_title == condensedTitle) {
+        return;
+    }
+    condensed_title = condensedTitle;
+    emit condensedTitleChanged();
+}
+
 void Options::setElectricBorderDelay(int electricBorderDelay)
 {
     if (electric_border_delay == electricBorderDelay) {
@@ -611,6 +594,15 @@ void Options::setElectricBorderTiling(bool electricBorderTiling)
     emit electricBorderTilingChanged();
 }
 
+void Options::setElectricBorderCornerRatio(float electricBorderCornerRatio)
+{
+    if (electric_border_corner_ratio == electricBorderCornerRatio) {
+        return;
+    }
+    electric_border_corner_ratio = electricBorderCornerRatio;
+    emit electricBorderCornerRatioChanged();
+}
+
 void Options::setBorderlessMaximizedWindows(bool borderlessMaximizedWindows)
 {
     if (borderless_maximized_windows == borderlessMaximizedWindows) {
@@ -728,6 +720,15 @@ void Options::setGlVSync(bool glVSync)
     emit glVSyncChanged();
 }
 
+void Options::setColorCorrected(bool colorCorrected)
+{
+    if (m_colorCorrected == colorCorrected) {
+        return;
+    }
+    m_colorCorrected = colorCorrected;
+    emit colorCorrectedChanged();
+}
+
 void Options::setXrenderSmoothScale(bool xrenderSmoothScale)
 {
     if (m_xrenderSmoothScale == xrenderSmoothScale) {
@@ -791,6 +792,15 @@ void Options::setGlStrictBindingFollowsDriver(bool glStrictBindingFollowsDriver)
     emit glStrictBindingFollowsDriverChanged();
 }
 
+void Options::setGlLegacy(bool glLegacy)
+{
+    if (m_glLegacy == glLegacy) {
+        return;
+    }
+    m_glLegacy = glLegacy;
+    emit glLegacyChanged();
+}
+
 void Options::setElectricBorders(int borders)
 {
     if (electric_borders == borders) {
@@ -834,6 +844,7 @@ unsigned long Options::loadConfig()
 
     KConfigGroup config(_config, "Windows");
     setShowGeometryTip(config.readEntry("GeometryTip", Options::defaultShowGeometryTip()));
+    setCondensedTitle(config.readEntry("CondensedTitle", Options::defaultCondensedTitle()));
 
     QString val;
 
@@ -872,10 +883,6 @@ unsigned long Options::loadConfig()
     setShadeHover(config.readEntry("ShadeHover", Options::defaultShadeHover()));
     setShadeHoverInterval(config.readEntry("ShadeHoverInterval", Options::defaultShadeHoverInterval()));
 
-    setTiling(config.readEntry("TilingOn", Options::defaultTiling()));
-    setTilingLayout(config.readEntry<int>("TilingDefaultLayout", Options::defaultTilingLayout()));
-    setTilingRaisePolicy(config.readEntry("TilingRaisePolicy", Options::defaultTilingRaisePolicy()));
-
     setClickRaise(config.readEntry("ClickRaise", Options::defaultClickRaise()));
 
     setBorderSnapZone(config.readEntry("BorderSnapZone", Options::defaultBorderSnapZone()));
@@ -900,6 +907,8 @@ unsigned long Options::loadConfig()
     setElectricBorderPushbackPixels(config.readEntry("ElectricBorderPushbackPixels", Options::defaultElectricBorderPushbackPixels()));
     setElectricBorderMaximize(config.readEntry("ElectricBorderMaximize", Options::defaultElectricBorderMaximize()));
     setElectricBorderTiling(config.readEntry("ElectricBorderTiling", Options::defaultElectricBorderTiling()));
+    const float ebr = config.readEntry("ElectricBorderCornerRatio", Options::defaultElectricBorderCornerRatio());
+    setElectricBorderCornerRatio(qMin(qMax(ebr, 0.0f), 1.0f));
 
     OpTitlebarDblClick = windowOperation(config.readEntry("TitlebarDoubleClickCommand", "Maximize"), true);
     setOpMaxButtonLeftClick(windowOperation(config.readEntry("MaximizeButtonLeftClickCommand", "Maximize"), true));
@@ -1019,6 +1028,9 @@ void Options::reloadCompositingSettings(bool force)
     if (!isGlStrictBindingFollowsDriver()) {
         setGlStrictBinding(config.readEntry("GLStrictBinding", Options::defaultGlStrictBinding()));
     }
+    setGlLegacy(config.readEntry("GLLegacy", Options::defaultGlLegacy()));
+
+    setColorCorrected(config.readEntry("GLColorCorrection", Options::defaultColorCorrected()));
 
     m_xrenderSmoothScale = config.readEntry("XRenderSmoothScale", false);
 
@@ -1128,6 +1140,11 @@ bool Options::showGeometryTip() const
     return show_geometry_tip;
 }
 
+bool Options::condensedTitle() const
+{
+    return condensed_title;
+}
+
 ElectricBorderAction Options::electricBorderAction(ElectricBorder edge) const
 {
     switch(edge) {
