@@ -47,6 +47,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "deleted.h"
 #include "effects.h"
 #include "overlaywindow.h"
+#include "paintredirector.h"
 #include "kwinxrenderutils.h"
 
 #include <X11/extensions/Xcomposite.h>
@@ -89,6 +90,7 @@ ScreenPaintData SceneXrender::screen_paint;
 SceneXrender::SceneXrender(Workspace* ws)
     : Scene(ws)
     , front(None)
+    , m_overlayWindow(new OverlayWindow())
     , init_ok(false)
 {
     if (!Extensions::renderAvailable()) {
@@ -115,6 +117,7 @@ SceneXrender::~SceneXrender()
     m_overlayWindow->destroy();
     foreach (Window * w, windows)
     delete w;
+    delete m_overlayWindow;
 }
 
 void SceneXrender::initXRender(bool createOverlay)
@@ -186,14 +189,14 @@ int SceneXrender::paint(QRegion damage, ToplevelList toplevels)
     if (m_overlayWindow->window())  // show the window only after the first pass, since
         m_overlayWindow->show();   // that pass may take long
 
-    flushBuffer(mask, damage);
+    present(mask, damage);
     // do cleanup
     stacking_order.clear();
 
     return renderTimer.elapsed();
 }
 
-void SceneXrender::flushBuffer(int mask, QRegion damage)
+void SceneXrender::present(int mask, QRegion damage)
 {
     if (mask & PAINT_SCREEN_REGION) {
         // Use the damage region as the clip region for the root window
@@ -373,10 +376,10 @@ QRect SceneXrender::Window::mapToScreen(int mask, const WindowPaintData &data, c
 
     if (mask & PAINT_WINDOW_TRANSFORMED) {
         // Apply the window transformation
-        r.moveTo(r.x() * data.xScale + data.xTranslate,
-                 r.y() * data.yScale + data.yTranslate);
-        r.setWidth(r.width() * data.xScale);
-        r.setHeight(r.height() * data.yScale);
+        r.moveTo(r.x() * data.xScale() + data.xTranslation(),
+                 r.y() * data.yScale() + data.yTranslation());
+        r.setWidth(r.width() * data.xScale());
+        r.setHeight(r.height() * data.yScale());
     }
 
     // Move the rectangle to the screen position
@@ -384,10 +387,10 @@ QRect SceneXrender::Window::mapToScreen(int mask, const WindowPaintData &data, c
 
     if (mask & PAINT_SCREEN_TRANSFORMED) {
         // Apply the screen transformation
-        r.moveTo(r.x() * screen_paint.xScale + screen_paint.xTranslate,
-                 r.y() * screen_paint.yScale + screen_paint.yTranslate);
-        r.setWidth(r.width() * screen_paint.xScale);
-        r.setHeight(r.height() * screen_paint.yScale);
+        r.moveTo(r.x() * screen_paint.xScale() + screen_paint.xTranslation(),
+                 r.y() * screen_paint.yScale() + screen_paint.yTranslation());
+        r.setWidth(r.width() * screen_paint.xScale());
+        r.setHeight(r.height() * screen_paint.yScale());
     }
 
     return r;
@@ -400,8 +403,8 @@ QPoint SceneXrender::Window::mapToScreen(int mask, const WindowPaintData &data,
 
     if (mask & PAINT_WINDOW_TRANSFORMED) {
         // Apply the window transformation
-        pt.rx() = pt.x() * data.xScale + data.xTranslate;
-        pt.ry() = pt.y() * data.yScale + data.yTranslate;
+        pt.rx() = pt.x() * data.xScale() + data.xTranslation();
+        pt.ry() = pt.y() * data.yScale() + data.yTranslation();
     }
 
     // Move the point to the screen position
@@ -409,8 +412,8 @@ QPoint SceneXrender::Window::mapToScreen(int mask, const WindowPaintData &data,
 
     if (mask & PAINT_SCREEN_TRANSFORMED) {
         // Apply the screen transformation
-        pt.rx() = pt.x() * screen_paint.xScale + screen_paint.xTranslate;
-        pt.ry() = pt.y() * screen_paint.yScale + screen_paint.yTranslate;
+        pt.rx() = pt.x() * screen_paint.xScale() + screen_paint.xTranslation();
+        pt.ry() = pt.y() * screen_paint.yScale() + screen_paint.yTranslation();
     }
 
     return pt;
@@ -440,7 +443,7 @@ void SceneXrender::Window::performPaint(int mask, QRegion region, WindowPaintDat
 {
     setTransformedShape(QRegion());  // maybe nothing will be painted
     // check if there is something to paint
-    bool opaque = isOpaque() && qFuzzyCompare(data.opacity, 1.0);
+    bool opaque = isOpaque() && qFuzzyCompare(data.opacity(), 1.0);
     /* HACK: It seems this causes painting glitches, disable temporarily
     if (( mask & PAINT_WINDOW_OPAQUE ) ^ ( mask & PAINT_WINDOW_TRANSLUCENT ))
         { // We are only painting either opaque OR translucent windows, not both
@@ -471,8 +474,8 @@ void SceneXrender::Window::performPaint(int mask, QRegion region, WindowPaintDat
     // do required transformations
     const QRect wr = mapToScreen(mask, data, QRect(0, 0, width(), height()));
     QRect cr = QRect(toplevel->clientPos(), toplevel->clientSize()); // Client rect (in the window)
-    double xscale = 1;
-    double yscale = 1;
+    qreal xscale = 1;
+    qreal yscale = 1;
     bool scaled = false;
 
     Client *client = dynamic_cast<Client*>(toplevel);
@@ -503,12 +506,12 @@ void SceneXrender::Window::performPaint(int mask, QRegion region, WindowPaintDat
     XRenderPictureAttributes attr;
 
     if (mask & PAINT_WINDOW_TRANSFORMED) {
-        xscale = data.xScale;
-        yscale = data.yScale;
+        xscale = data.xScale();
+        yscale = data.yScale();
     }
     if (mask & PAINT_SCREEN_TRANSFORMED) {
-        xscale *= screen_paint.xScale;
-        yscale *= screen_paint.yScale;
+        xscale *= screen_paint.xScale();
+        yscale *= screen_paint.yScale();
     }
     if (!qFuzzyCompare(xscale, 1.0) || !qFuzzyCompare(yscale, 1.0)) {
         scaled = true;
@@ -582,25 +585,26 @@ void SceneXrender::Window::performPaint(int mask, QRegion region, WindowPaintDat
     const QPixmap *top = NULL;
     const QPixmap *right = NULL;
     const QPixmap *bottom = NULL;
+    PaintRedirector *redirector = NULL;
     QRect dtr, dlr, drr, dbr;
     if (client || deleted) {
         if (client && !client->noBorder()) {
-            client->ensureDecorationPixmapsPainted();
+            redirector = client->decorationPaintRedirector();
             noBorder = client->noBorder();
-            left   = client->leftDecoPixmap();
-            top    = client->topDecoPixmap();
-            right  = client->rightDecoPixmap();
-            bottom = client->bottomDecoPixmap();
             client->layoutDecorationRects(dlr, dtr, drr, dbr, Client::WindowRelative);
         }
         if (deleted && !deleted->noBorder()) {
             noBorder = deleted->noBorder();
-            left   = deleted->leftDecoPixmap();
-            top    = deleted->topDecoPixmap();
-            right  = deleted->rightDecoPixmap();
-            bottom = deleted->bottomDecoPixmap();
+            redirector = deleted->decorationPaintRedirector();
             deleted->layoutDecorationRects(dlr, dtr, drr, dbr);
         }
+        if (redirector) {
+            redirector->ensurePixmapsPainted();
+            left   = redirector->leftDecoPixmap();
+            top    = redirector->topDecoPixmap();
+            right  = redirector->rightDecoPixmap();
+            bottom = redirector->bottomDecoPixmap();
+        }
         if (!noBorder) {
             MAP_RECT_TO_TARGET(dtr);
             MAP_RECT_TO_TARGET(dlr);
@@ -652,7 +656,7 @@ XRenderComposite(display(), PictOpOver, m_xrenderShadow->shadowPixmap(SceneXRend
 
         //shadow
         if (wantShadow) {
-            Picture shadowAlpha = opaque ? None : alphaMask(data.opacity);
+            Picture shadowAlpha = opaque ? None : alphaMask(data.opacity());
             RENDER_SHADOW_TILE(TopLeft, stlr);
             RENDER_SHADOW_TILE(Top, str);
             RENDER_SHADOW_TILE(TopRight, strr);
@@ -666,7 +670,7 @@ XRenderComposite(display(), PictOpOver, m_xrenderShadow->shadowPixmap(SceneXRend
 
         // Paint the window contents
         if (!(client && client->isShade())) {
-            Picture clientAlpha = opaque ? None : alphaMask(data.opacity);
+            Picture clientAlpha = opaque ? None : alphaMask(data.opacity());
             XRenderComposite(display(), clientRenderOp, pic, clientAlpha, renderTarget, cr.x(), cr.y(), 0, 0, dr.x(), dr.y(), dr.width(), dr.height());
             if (!opaque)
                 transformed_shape = QRegion();
@@ -678,18 +682,21 @@ XRenderComposite(display(), PictOpOver, _PART_->x11PictureHandle(), decorationAl
 
         if (client || deleted) {
             if (!noBorder) {
-                Picture decorationAlpha = alphaMask(data.opacity * data.decoration_opacity);
+                Picture decorationAlpha = alphaMask(data.opacity() * data.decorationOpacity());
                 RENDER_DECO_PART(top, dtr);
                 RENDER_DECO_PART(left, dlr);
                 RENDER_DECO_PART(right, drr);
                 RENDER_DECO_PART(bottom, dbr);
             }
+            if (redirector) {
+                redirector->markAsRepainted();
+            }
         }
 #undef RENDER_DECO_PART
 
-        if (data.brightness < 1.0) {
+        if (data.brightness() < 1.0) {
             // fake brightness change by overlaying black
-            XRenderColor col = { 0, 0, 0, 0xffff *(1 - data.brightness) * data.opacity };
+            XRenderColor col = { 0, 0, 0, static_cast<unsigned short>(0xffff *(1 - data.brightness()) * data.opacity()) };
             if (blitInTempPixmap) {
                 XRenderFillRectangle(display(), PictOpOver, renderTarget, &col,
                                      -temp_visibleRect.left(), -temp_visibleRect.top(), width(), height());
