@@ -34,6 +34,7 @@
 #include <KDebug>
 
 #include "powerdevilpolicyagent.h"
+#include "screensaver_interface.h"
 
 struct NamedDBusObjectPath
 {
@@ -161,6 +162,15 @@ QString PolicyAgent::getNamedPathProperty(const QString &path, const QString &if
     return QString();
 }
 
+void PolicyAgent::forceLockAndWait()
+{
+    OrgFreedesktopScreenSaverInterface screenSaveriface("org.freedesktop.ScreenSaver",
+                                                        "/ScreenSaver",
+                                                        QDBusConnection::sessionBus());
+    QDBusPendingReply< void > reply = screenSaveriface.Lock();
+    reply.waitForFinished();
+}
+
 void PolicyAgent::onSessionHandlerRegistered(const QString & serviceName)
 {
     if (serviceName == SYSTEMD_LOGIN1_SERVICE) {
@@ -193,6 +203,8 @@ void PolicyAgent::onSessionHandlerRegistered(const QString & serviceName)
             return;
         }
 
+        // listen to the systemd-login1 session's Lock signal
+        connect(m_sdSessionInterface.data(), SIGNAL(Lock()), this, SLOT(forceLockAndWait()));
 
         // now let's obtain the seat
         QString seatPath = getNamedPathProperty(sessionPath, SYSTEMD_LOGIN1_SESSION_IFACE, "Seat");
